@@ -159,7 +159,7 @@ class ExtractFeaturesFrom14bps(object):
             for k, v in self.hull_dict.items():
                 self.out_data[k] = v
 
-            self.out_data['Sum___euclidean_distance_hull_M1_M2'] = self.out_data['M1_hull_sum_euclidean'] + self.out_data['M2_hull_sum_euclidean']
+            self.out_data['Sum_euclidean_distance_hull_M1_M2'] = self.out_data['M1_hull_sum_euclidean'] + self.out_data['M2_hull_sum_euclidean']
             self.out_data['Total_movement_centroids'] = self.out_data['Movement_mouse_1_centroid'] + self.out_data['Movement_mouse_2_centroid']
             mouse_1_movement_cols = [x for x in self.out_data.columns if x.startswith('Movement_mouse_1_')]
             mouse_2_movement_cols = [x for x in self.out_data.columns if x.startswith('Movement_mouse_2_')]
@@ -171,11 +171,11 @@ class ExtractFeaturesFrom14bps(object):
 
             for window in self.roll_windows_values:
                 col_name = 'Sum_euclid_distances_hull_median_{}'.format(str(window))
-                self.out_data[col_name] = self.out_data['Sum___euclidean_distance_hull_M1_M2'].rolling(int(window), min_periods=1).median()
+                self.out_data[col_name] = self.out_data['Sum_euclidean_distance_hull_M1_M2'].rolling(int(window), min_periods=1).median()
                 col_name = 'Sum_euclid_distances_hull_mean_{}'.format(str(window))
-                self.out_data[col_name] = self.out_data['Sum___euclidean_distance_hull_M1_M2'].rolling(int(window), min_periods=1).mean()
+                self.out_data[col_name] = self.out_data['Sum_euclidean_distance_hull_M1_M2'].rolling(int(window), min_periods=1).mean()
                 col_name = 'Sum_euclid_distances_hull_sum_{}'.format(str(window))
-                self.out_data[col_name] = self.out_data['Sum___euclidean_distance_hull_M1_M2'].rolling(int(window), min_periods=1).sum()
+                self.out_data[col_name] = self.out_data['Sum_euclidean_distance_hull_M1_M2'].rolling(int(window), min_periods=1).sum()
 
             for window in self.roll_windows_values:
                 col_name = 'Movement_median_{}'.format(str(window))
@@ -332,7 +332,7 @@ class ExtractFeaturesFrom14bps(object):
 
             print('Calculating deviations...')
             self.out_data['Total_movement_all_bodyparts_both_mice_deviation'] = (self.out_data['Total_movement_all_bodyparts_both_mice'].mean() - self.out_data['Total_movement_all_bodyparts_both_mice'])
-            self.out_data['Sum_euclid_distances_hull_deviation'] = (self.out_data['Sum___euclidean_distance_hull_M1_M2'].mean() - self.out_data['Sum___euclidean_distance_hull_M1_M2'])
+            self.out_data['Sum_euclid_distances_hull_deviation'] = (self.out_data['Sum_euclidean_distance_hull_M1_M2'].mean() - self.out_data['Sum_euclidean_distance_hull_M1_M2'])
             self.out_data['M1_smallest_euclid_distances_hull_deviation'] = (self.out_data['M1_hull_small_euclidean'].mean() - self.out_data['M1_hull_small_euclidean'])
             self.out_data['M1_largest_euclid_distances_hull_deviation'] = (self.out_data['M1_hull_large_euclidean'].mean() - self.out_data['M1_hull_large_euclidean'])
             self.out_data['M1_mean_euclid_distances_hull_deviation'] = (self.out_data['M1_hull_mean_euclidean'].mean() - self.out_data['M1_hull_mean_euclidean'])
