@@ -196,9 +196,9 @@ class ExtractFeaturesFrom7bps(object):
 
             print('Calculating deviations...')
             self.out_data['Total_movement_all_bodyparts_deviation'] = (self.out_data['Total_movement_all_bodyparts_M1'].mean() - self.out_data['Total_movement_all_bodyparts_M1'])
-            self.out_data['M1_smallest_euclid_distances_hull_deviation'] = (self.out_data['M1_smallest_euclidean_distance_hull'].mean() - self.out_data['M1_smallest___euclidean_distance_hull'])
-            self.out_data['M1_largest_euclid_distances_hull_deviation'] = (self.out_data['M1_largest_euclidean_distance_hull'].mean() - self.out_data['M1_largest___euclidean_distance_hull'])
-            self.out_data['M1_mean_euclid_distances_hull_deviation'] = (self.out_data['M1_mean_euclidean_distance_hull'].mean() - self.out_data['M1_mean___euclidean_distance_hull'])
+            self.out_data['M1_smallest_euclid_distances_hull_deviation'] = (self.out_data['M1_smallest_euclidean_distance_hull'].mean() - self.out_data['M1_smallest_euclidean_distance_hull'])
+            self.out_data['M1_largest_euclid_distances_hull_deviation'] = (self.out_data['M1_largest_euclidean_distance_hull'].mean() - self.out_data['M1_largest_euclidean_distance_hull'])
+            self.out_data['M1_mean_euclid_distances_hull_deviation'] = (self.out_data['M1_mean_euclidean_distance_hull'].mean() - self.out_data['M1_mean_euclidean_distance_hull'])
             self.out_data['Total_angle_deviation'] = (self.out_data['Mouse_angle'].mean() - self.out_data['Mouse_angle'])
             self.out_data['Movement_mouse_deviation_centroid'] = (self.out_data['Movement_mouse_centroid'].mean() - self.out_data['Movement_mouse_centroid'])
             self.out_data['Mouse_polygon_deviation'] = (self.out_data['Mouse_poly_area'].mean() - self.out_data['Mouse_poly_area'])
