@@ -119,10 +119,10 @@ class ExtractFeaturesFrom8bps(object):
                 animal_frm = np.reshape(animal_frm, (-1, 2))
                 animal_dists = scipy.spatial.distance.cdist(animal_frm, animal_frm, metric='euclidean')
                 animal_dists = animal_dists[animal_dists != 0]
-                self.hull_dict['M1_largest___euclidean_distance_hull'].append(np.amax(animal_dists) / self.px_per_mm)
-                self.hull_dict['M1_smallest___euclidean_distance_hull'].append(np.amin(animal_dists) / self.px_per_mm)
-                self.hull_dict['M1_mean___euclidean_distance_hull'].append(np.mean(animal_dists) / self.px_per_mm)
-                self.hull_dict['M1_sum___euclidean_distance_hull'].append(np.sum(animal_dists) / self.px_per_mm)
+                self.hull_dict['M1_largest_euclidean_distance_hull'].append(np.amax(animal_dists) / self.px_per_mm)
+                self.hull_dict['M1_smallest_euclidean_distance_hull'].append(np.amin(animal_dists) / self.px_per_mm)
+                self.hull_dict['M1_mean_euclidean_distance_hull'].append(np.mean(animal_dists) / self.px_per_mm)
+                self.hull_dict['M1_sum_euclidean_distance_hull'].append(np.sum(animal_dists) / self.px_per_mm)
             for k, v in self.hull_dict.items():
                 self.out_data[k] = v
 
@@ -217,9 +217,9 @@ class ExtractFeaturesFrom8bps(object):
             print('Calculating deviations...')
 
             self.out_data['Total_movement_all_bodyparts_deviation'] = (self.out_data['Total_movement_all_bodyparts_M1'].mean() - self.out_data['Total_movement_all_bodyparts_M1'])
-            self.out_data['M1_smallest_euclid_distances_hull_deviation'] = (self.out_data['M1_smallest_euclidean_distance_hull'].mean() - self.out_data['M1_smallest___euclidean_distance_hull'])
-            self.out_data['M1_largest_euclid_distances_hull_deviation'] = (self.out_data['M1_largest_euclidean_distance_hull'].mean() - self.out_data['M1_largest___euclidean_distance_hull'])
-            self.out_data['M1_mean_euclid_distances_hull_deviation'] = (self.out_data['M1_mean_euclidean_distance_hull'].mean() - self.out_data['M1_mean___euclidean_distance_hull'])
+            self.out_data['M1_smallest_euclid_distances_hull_deviation'] = (self.out_data['M1_smallest_euclidean_distance_hull'].mean() - self.out_data['M1_smallest_euclidean_distance_hull'])
+            self.out_data['M1_largest_euclid_distances_hull_deviation'] = (self.out_data['M1_largest_euclidean_distance_hull'].mean() - self.out_data['M1_largest_euclidean_distance_hull'])
+            self.out_data['M1_mean_euclid_distances_hull_deviation'] = (self.out_data['M1_mean_euclidean_distance_hull'].mean() - self.out_data['M1_mean_euclidean_distance_hull'])
             self.out_data['Total_angle_deviation'] = (self.out_data['Mouse_angle'].mean() - self.out_data['Mouse_angle'])
             self.out_data['Movement_mouse_deviation_centroid'] = (self.out_data['Movement_mouse_centroid'].mean() - self.out_data['Movement_mouse_centroid'])
             self.out_data['Mouse_polygon_deviation'] = (self.out_data['Mouse_poly_area'].mean() - self.out_data['Mouse_poly_area'])
