@@ -61,13 +61,12 @@ def get_video_meta_data(video_path: str):
     video_data['width'] = int(cap.get(cv2.CAP_PROP_FRAME_WIDTH))
     video_data['height'] = int(cap.get(cv2.CAP_PROP_FRAME_HEIGHT))
     video_data['frame_count'] = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))
-    video_data['video_length_s'] = int(video_data['frame_count'] / video_data['fps'])
     for k, v in video_data.items():
         if v == 0:
             print('SIMBA WARNING: Video {} has {} of {}.'.format(video_data['video_name'], k, str(v)))
             raise ValueError('SIMBA WARNING: Video {} has {} of {}.'.format(video_data['video_name'], k, str(v)))
     video_data['resolution_str'] = str('{} x {}'.format(video_data['width'], video_data['height']))
-
+    video_data['video_length_s'] = int(video_data['frame_count'] / video_data['fps'])
     return video_data
 
 def check_directionality_viable(animal_bp_dict: dict):
@@ -150,7 +149,7 @@ def check_multi_animal_status(config: configparser.ConfigParser,
                 multi_animal_id_lst.append('Animal_{}'.format(str(animal + 1)))
             multi_animal_status = False
 
-    return multi_animal_status, multi_animal_id_lst
+    return multi_animal_status, multi_animal_id_lst[:no_animals]
 
 
 def line_length(p: list,
@@ -747,7 +746,9 @@ def find_core_cnt():
     cpu_cnt_to_use: int
     """
     cpu_cnt = multiprocessing.cpu_count()
-    cpu_cnt_to_use = int(cpu_cnt / 2)
+    cpu_cnt_to_use = int(cpu_cnt / 4)
+    if cpu_cnt_to_use < 1:
+        cpu_cnt_to_use = 1
     return cpu_cnt, cpu_cnt_to_use
 
 def remove_a_folder(folder_dir: str):
