@@ -58,7 +58,7 @@ class ImportSLEAP(object):
     ----------
     >>> slp_importer = ImportSLEAP(project_path="MyConfigPath", data_folder=r'MySLPDataFolder', actor_IDs=['Mouse_1', 'Mouse_2'], interpolation_settings="Body-parts: Nearest", smoothing_settings = {'Method': 'Savitzky Golay', 'Parameters': {'Time_window': '200'}})
     >>> slp_importer.initate_import_slp()
-    >>> slp_importer.__visualize_sleap()
+    >>> slp_importer.visualize_sleap()
     >>> slp_importer.perform_interpolation()
     >>> slp_importer.perform_smothing()
     """
@@ -94,6 +94,30 @@ class ImportSLEAP(object):
 
         print('Converting .SLP file(s) into SimBA dataframes...')
 
+    def visualize_sleap(self):
+        self.frame_number = 0
+        multi_animal_status, multi_animal_id_lst = check_multi_animal_status(self.config, self.animals_no)
+        Xcols, Ycols, Pcols = getBpNames(self.ini_path)
+        color_lst = createColorListofList(self.animals_no, len(self.analysis_dict['ordered_bps']))
+        self.animal_bp_dict = create_body_part_dictionary(multi_animal_status, multi_animal_id_lst, self.animals_no,
+                                                          Xcols, Ycols, [], color_lst)
+        for file_path in self.save_paths_lst:
+            self.data_df = read_df(file_path, self.file_format)
+            self.data_df.columns = getBpHeaders(self.ini_path)
+            _, video_name, _ = get_fn_ext(file_path)
+            video_path = find_video_of_file(self.video_folder, video_name)
+            self.cap = cv2.VideoCapture(video_path)
+            self.cap.set(1, self.frame_number)
+            if not self.cap.isOpened():
+                raise Exception('Can\'t open video file ' + video_path)
+            self.video_meta_data = get_video_meta_data(video_path)
+            mySpaceScale, myRadius, myResolution, myFontScale = 40, 10, 1500, 1.2
+            maxResDimension = max(self.video_meta_data['width'], self.video_meta_data['height'])
+            self.circle_scale = int(myRadius / (myResolution / maxResDimension))
+            self.font_scale = float(myFontScale / (myResolution / maxResDimension))
+            self.spacing_scale = int(mySpaceScale / (myResolution / maxResDimension))
+            self.__show_clean_window()
+
     def __update_config(self):
         self.config.set("General settings", "animal_no", str(self.animals_no))
         with open(self.project_path, "w+") as f:
@@ -249,7 +273,7 @@ class ImportSLEAP(object):
         print('Re-organized {} for SimBA analysis...'.format(os.path.basename(self.save_path)))
 
     def __create_first_side_img(self):
-        self.side_img = np.ones((int(self.video_meta_data['height'] / 2), self.video_meta_data['width'], 3))
+        self.side_img = np.ones((int(self.video_meta_data['height'] / 1.5), self.video_meta_data['width'], 3))
         cv2.putText(self.side_img, 'Current video: ' + self.video_name, (10, int(self.spacing_scale)), cv2.FONT_HERSHEY_SIMPLEX, self.font_scale, (255, 255, 255), 2)
         cv2.putText(self.side_img, 'Can you assign identities based on the displayed frame ?', (10, int(self.spacing_scale * (self.add_spacer * 2))), cv2.FONT_HERSHEY_SIMPLEX, self.font_scale,(255, 255, 255), 2)
         cv2.putText(self.side_img, 'Press "x" to display new - random - frame', (10, int(self.spacing_scale * (self.add_spacer * 3))), cv2.FONT_HERSHEY_SIMPLEX, self.font_scale, (255, 255, 0), 2)
@@ -275,41 +299,18 @@ class ImportSLEAP(object):
                 cv2.imshow('Define animal IDs', self.concat_img)
 
     def __create_third_side_img(self):
-        self.side_img = np.ones((int(self.video_meta_data['height'] / 2), self.video_meta_data['width'], 3))
+        self.side_img = np.ones((int(self.video_meta_data['height'] / 1.5), self.video_meta_data['width'], 3))
         cv2.putText(self.side_img, 'Current video: ' + self.video_name, (10, int(self.spacing_scale)), cv2.FONT_HERSHEY_SIMPLEX, self.font_scale, (255, 255, 255), 2)
         cv2.putText(self.side_img, 'Are you happy with your assigned identities ?', (10, int(self.spacing_scale * (self.add_spacer * 2))), cv2.FONT_HERSHEY_SIMPLEX, self.font_scale, (255, 255, 255), 2)
         cv2.putText(self.side_img, 'Press "c" to continue (to finish, or proceed to the next video)', (10, int(self.spacing_scale * (self.add_spacer * 3))), cv2.FONT_HERSHEY_SIMPLEX, self.font_scale, (255, 255, 0), 2)
         cv2.putText(self.side_img, 'Press "x" to re-start assigning identities', (10, int(self.spacing_scale * (self.add_spacer * 4))), cv2.FONT_HERSHEY_SIMPLEX, self.font_scale, (0, 255, 255), 2)
 
-    def __visualize_sleap(self):
-        self.frame_number = 0
-        multi_animal_status, multi_animal_id_lst = check_multi_animal_status(self.config, self.animals_no)
-        Xcols, Ycols, Pcols = getBpNames(self.ini_path)
-        color_lst = createColorListofList(self.animals_no, len(self.analysis_dict['ordered_bps']))
-        self.animal_bp_dict = create_body_part_dictionary(multi_animal_status, multi_animal_id_lst, self.animals_no, Xcols, Ycols, [], color_lst)
-        for file_path in self.save_paths_lst:
-            self.data_df = read_df(file_path, self.file_format)
-            self.data_df.columns = getBpHeaders(self.ini_path)
-            _, video_name, _ = get_fn_ext(file_path)
-            video_path = find_video_of_file(self.video_folder, video_name)
-            self.cap = cv2.VideoCapture(video_path)
-            self.cap.set(1, self.frame_number)
-            if not self.cap.isOpened():
-                raise Exception('Can\'t open video file ' + video_path)
-            self.video_meta_data = get_video_meta_data(video_path)
-            mySpaceScale, myRadius, myResolution, myFontScale = 40, 10, 1500, 1.2
-            maxResDimension = max(self.video_meta_data['width'], self.video_meta_data['height'])
-            self.circle_scale = int(myRadius / (myResolution / maxResDimension))
-            self.font_scale = float(myFontScale / (myResolution / maxResDimension))
-            self.spacing_scale = int(mySpaceScale / (myResolution / maxResDimension))
-            self.__show_clean_window()
-
     def __assign_individuals(self):
         self.ID_cords = {}
         for animal_cnt, animal in enumerate(self.animal_bp_dict.keys()):
             self.current_animal = animal
             self.animal_cnt = animal_cnt
-            self.side_img = np.ones((int(self.video_meta_data['height'] / 2), self.video_meta_data['width'], 3))
+            self.side_img = np.ones((int(self.video_meta_data['height'] / 1.5), self.video_meta_data['width'], 3))
             cv2.putText(self.side_img, 'Double left mouse click on:', (10, int(self.spacing_scale)), cv2.FONT_HERSHEY_SIMPLEX, self.font_scale, (255, 255, 255), 2)
             cv2.putText(self.side_img, animal, (10, int(self.spacing_scale * (self.add_spacer * 2))), cv2.FONT_HERSHEY_SIMPLEX, self.font_scale, (255, 255, 0), 2)
             self.concat_img = np.uint8(np.concatenate((self.frame, self.side_img), axis=0))
@@ -434,12 +435,6 @@ class ImportSLEAP(object):
 # print('All SLEAP imports complete.')
 #
 
-
-
-
-
-
-
 # test = ImportSLEAP(project_path="Z:\DeepLabCut\DLC_extract\Troubleshooting\SLEAP_9Test_2\project_folder\project_config.ini",
 #             data_folder='Z:\DeepLabCut\DLC_extract\Troubleshooting\SLEAP_9Test_2\data',
 #             actor_IDs=['Animal_1', 'Animal_2', 'Animal_3', 'Animal_4', 'Animal_5'],
@@ -466,7 +461,7 @@ class ImportSLEAP(object):
 # test.perform_interpolation()
 # test.perform_smothing()
 # print('All SLEAP imports complete.')
-
-
+#
+#
 
 
