@@ -34,7 +34,6 @@ def change_img_format(directory: str,
     Example
     ----------
     >>> _ = change_img_format(directory='MyDirectoryWImages', file_type_in='bmp', file_type_out='png')
-    >>> inferencer.run_models()
 
     """
     if not os.path.isdir(directory):
@@ -191,6 +190,7 @@ def change_fps_of_multiple_videos(directory: str,
         raise ValueError()
     for file_cnt, file_path in enumerate(video_paths):
         dir_name, file_name, ext = get_fn_ext(filepath=file_path)
+        print('Converting FPS for {}...'.format(file_name))
         save_path = os.path.join(dir_name, file_name + '_fps_{}{}'.format(str(fps), str(ext)))
         command = str('ffmpeg -i ') + str(file_path) + ' -filter:v fps=fps=' + str(fps) + ' ' + '"' + save_path + '"'
         subprocess.call(command, shell=True)
@@ -695,6 +695,6 @@ def frames_to_movie(directory: str,
     ffmpeg_fn = os.path.join(directory, '%d.{}'.format(img_format))
     save_path = os.path.join(os.path.dirname(directory), os.path.basename(directory) + '.mp4')
     command = str('ffmpeg -y -r ' + str(fps) + ' -f image2 -s ' + str(img_h) + 'x' + str(img_w) + ' -i ' + '"' + ffmpeg_fn + '"' + ' -vcodec libx264 -b ' + str(bitrate) + 'k ' + '"' + str(save_path) + '"')
-    print('Creating {}...'.format(os.path.basename(save_path)))
+    print('Creating {} from {} images...'.format(os.path.basename(save_path), str(len(img_paths_in_folder))))
     subprocess.call(command, shell=True)
     print('SIMBA COMPLETE: Video created at {}'.format(save_path))
\ No newline at end of file
